@@ -3,12 +3,10 @@
 from abc import ABC, abstractmethod
 from dataclasses import InitVar, dataclass
 from itertools import accumulate
-from typing import Iterable, Optional
 
 from nautilus_namecodes.namecodes_dataclasses import (
     BlockCodes,
     PlaneCodes,
-    Range,
     SectionCodes,
 )
 
@@ -25,7 +23,6 @@ class CommonValues:
     """Attributes that are common all generation data classes."""
 
     name: str
-    description: Optional[str]
 
 
 class CommonMethods(ABC):  # pylint: disable=too-few-public-methods
@@ -78,10 +75,7 @@ class Section(CommonValues, CommonMethods):
         _codes: dict[int, str] = dict(zip(_used_codepoints, _values_formated))
 
         return SectionCodes(
-            name=self.name,
-            description=self.description,
-            codepoints_allocated=Range.mk_range(_codepoints_allocated),
-            codes=_codes,
+            name=self.name, codepoints_allocated=_codepoints_allocated, codes=_codes
         )
 
     @staticmethod
@@ -101,7 +95,7 @@ class Section(CommonValues, CommonMethods):
 class Block(CommonValues, CommonMethods):
     """A Group of Sections"""
 
-    sections: Iterable[Section]
+    sections: list[Section]
     pages_minimum: InitVar[int] = 0
 
     def __post_init__(self, pages_minimum: int) -> None:
@@ -144,8 +138,7 @@ class Block(CommonValues, CommonMethods):
 
         _block_codes: BlockCodes = BlockCodes(  # pylint: disable=no-value-for-parameter
             name=self.name,
-            description=self.description,
-            codepoints_allocated=Range.mk_range(_codepoints_allocated),
+            codepoints_allocated=_codepoints_allocated,
             sections=_section_codes,
         )
 
@@ -161,13 +154,7 @@ class Plane(CommonValues, CommonMethods):
     def get_block_page_allocations(self) -> list[int]:
         """Get the number of allocated pages per Block"""
 
-        block: Block
-        allocations: list[int] = []
-
-        for block in self.blocks:
-            allocations.append(block.get_pages_allocated())
-
-        return allocations
+        return [block.get_pages_allocated() for block in self.blocks]
 
     def get_pages_allocated(self) -> int:
         return sum(self.get_block_page_allocations())
@@ -200,8 +187,7 @@ class Plane(CommonValues, CommonMethods):
 
         _plane_codes: PlaneCodes = PlaneCodes(  # pylint: disable=no-value-for-parameter
             name=self.name,
-            description=self.description,
-            codepoints_allocated=Range.mk_range(_codepoints_allocated),
+            codepoints_allocated=_codepoints_allocated,
             blocks=_block_codes,
         )
 
